__author__ = 'Ricardo Galli @ APSL'
__description__ = "A very efficient and simple Django middleware to retrieve the real IP address from the headers sent by a trusted load balancer"
__version__ = '1.0'
